@@ -25,7 +25,7 @@ from lastversion import lastversion
 ##########################################################################################################################
 # update version here (will be displayed on the main layout)
 # Support for: u = ubuntu, w = windows, m = macintosh
-apscale_version = '1.0.3'
+apscale_version = '1.0.5'
 
 ## check for the latest version of TTT
 try:
@@ -524,10 +524,10 @@ def main():
                 					]
 
                 # create the demultiplexing window
-                blast_window = sg.Window('NCBI Blast', layout_sample_renaming, keep_on_top=False)
+                rename_files_window = sg.Window('Rename files', layout_sample_renaming, keep_on_top=False)
                 while (True):
                     ######################################
-                    event, values2 = blast_window.Read()
+                    event, values2 = rename_files_window.Read()
                     ######################################
 
                     if event in ('Exit', None):
@@ -548,6 +548,8 @@ def main():
                             rename_files(values2['paired_end_reads'], path_to_outdirs)
                             sg.Popup('All files were renamed accordingly.')
 
+                rename_files_window.Close()
+
             if event == 'open_quality_control':
 
                 MP_window.hide()
